# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_keyvault.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$azure/azure_microsoft_keyvault.proto\x12$oak9.tython.azure.microsoft_keyvault\x1a\x13shared/shared.proto\"\x99\x03\n\x12Microsoft_KeyVault\x12<\n\x06vaults\x18\x01 \x01(\x0b\x32,.oak9.tython.azure.microsoft_keyvault.Vaults\x12Z\n\x16vaults_access_policies\x18\x02 \x03(\x0b\x32:.oak9.tython.azure.microsoft_keyvault.VaultsAccessPolicies\x12\x45\n\x0bvaults_keys\x18\x03 \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_keyvault.VaultsKeys\x12K\n\x0evaults_secrets\x18\x04 \x03(\x0b\x32\x33.oak9.tython.azure.microsoft_keyvault.VaultsSecrets\x12U\n\x13vaults_certificates\x18\x05 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_keyvault.VaultsCertificates\"q\n\x12VaultsCertificates\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0ckey_vault_id\x18\x03 \x01(\t\"\xc1\x02\n\rVaultsSecrets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12J\n\nattributes\x18\x03 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_keyvault.SecretAttributes\x12\x14\n\x0c\x63ontent_type\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\t\x12K\n\x04tags\x18\x06 \x03(\x0b\x32=.oak9.tython.azure.microsoft_keyvault.VaultsSecrets.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"=\n\x10SecretAttributes\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0b\n\x03\x65xp\x18\x02 \x01(\t\x12\x0b\n\x03nbf\x18\x03 \x01(\t\"\xdc\x02\n VaultsPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12O\n\x10private_endpoint\x18\x04 \x01(\x0b\x32\x35.oak9.tython.azure.microsoft_keyvault.PrivateEndpoint\x12v\n%private_link_service_connection_state\x18\x05 \x01(\x0b\x32G.oak9.tython.azure.microsoft_keyvault.PrivateLinkServiceConnectionState\x12\x1a\n\x12provisioning_state\x18\x06 \x01(\t\"b\n!PrivateLinkServiceConnectionState\x12\x18\n\x10\x61\x63tions_required\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1f\n\x0fPrivateEndpoint\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xf6\x03\n\nVaultsKeys\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12G\n\nattributes\x18\x03 \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_keyvault.KeyAttributes\x12\x12\n\ncurve_name\x18\x04 \x01(\t\x12\x0f\n\x07key_ops\x18\x05 \x03(\t\x12\x10\n\x08key_size\x18\x06 \x01(\x05\x12\x0b\n\x03kty\x18\x07 \x01(\t\x12N\n\x0erelease_policy\x18\x08 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_keyvault.KeyReleasePolicy\x12M\n\x0frotation_policy\x18\t \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_keyvault.RotationPolicy\x12H\n\x04tags\x18\n \x03(\x0b\x32:.oak9.tython.azure.microsoft_keyvault.VaultsKeys.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb7\x01\n\x0eRotationPolicy\x12U\n\nattributes\x18\x01 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_keyvault.KeyRotationPolicyAttributes\x12N\n\x10lifetime_actions\x18\x02 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_keyvault.LifetimeAction\"\x8e\x01\n\x0eLifetimeAction\x12<\n\x06\x61\x63tion\x18\x01 \x01(\x0b\x32,.oak9.tython.azure.microsoft_keyvault.Action\x12>\n\x07trigger\x18\x02 \x01(\x0b\x32-.oak9.tython.azure.microsoft_keyvault.Trigger\"@\n\x07Trigger\x12\x19\n\x11time_after_create\x18\x01 \x01(\t\x12\x1a\n\x12time_before_expiry\x18\x02 \x01(\t\"\x16\n\x06\x41\x63tion\x12\x0c\n\x04type\x18\x01 \x01(\t\"2\n\x1bKeyRotationPolicyAttributes\x12\x13\n\x0b\x65xpiry_time\x18\x01 \x01(\t\"6\n\x10KeyReleasePolicy\x12\x14\n\x0c\x63ontent_type\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"N\n\rKeyAttributes\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0b\n\x03\x65xp\x18\x02 \x01(\t\x12\x12\n\nexportable\x18\x03 \x01(\x08\x12\x0b\n\x03nbf\x18\x04 \x01(\t\"\xaf\x01\n\x14VaultsAccessPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12P\n\x0f\x61\x63\x63\x65ss_policies\x18\x03 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_keyvault.AccessPolicyEntry\"\x8a\x07\n\x06Vaults\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12P\n\x0f\x61\x63\x63\x65ss_policies\x18\x04 \x03(\x0b\x32\x37.oak9.tython.azure.microsoft_keyvault.AccessPolicyEntry\x12\x13\n\x0b\x63reate_mode\x18\x05 \x01(\t\x12\x1e\n\x16\x65nabled_for_deployment\x18\x06 \x01(\x08\x12#\n\x1b\x65nabled_for_disk_encryption\x18\x07 \x01(\x08\x12\'\n\x1f\x65nabled_for_template_deployment\x18\x08 \x01(\x08\x12\x1f\n\x17\x65nable_purge_protection\x18\t \x01(\x08\x12!\n\x19\x65nable_rbac_authorization\x18\n \x01(\x08\x12\x1a\n\x12\x65nable_soft_delete\x18\x0b \x01(\x08\x12J\n\x0cnetwork_acls\x18\x0c \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_keyvault.NetworkRuleSet\x12\x1a\n\x12provisioning_state\x18\r \x01(\t\x12\x1d\n\x15public_network_access\x18\x0e \x01(\t\x12\x36\n\x03sku\x18\x0f \x01(\x0b\x32).oak9.tython.azure.microsoft_keyvault.Sku\x12%\n\x1dsoft_delete_retention_in_days\x18\x10 \x01(\x05\x12\x11\n\ttenant_id\x18\x11 \x01(\t\x12\x11\n\tvault_uri\x18\x12 \x01(\t\x12\x44\n\x04tags\x18\x13 \x03(\x0b\x32\x36.oak9.tython.azure.microsoft_keyvault.Vaults.TagsEntry\x12s\n#vaults_private_endpoint_connections\x18\x14 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_keyvault.VaultsPrivateEndpointConnections\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"#\n\x03Sku\x12\x0e\n\x06\x66\x61mily\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd1\x01\n\x0eNetworkRuleSet\x12\x0e\n\x06\x62ypass\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x65\x66\x61ult_action\x18\x02 \x01(\t\x12>\n\x08ip_rules\x18\x03 \x03(\x0b\x32,.oak9.tython.azure.microsoft_keyvault.IPRule\x12W\n\x15virtual_network_rules\x18\x04 \x03(\x0b\x32\x38.oak9.tython.azure.microsoft_keyvault.VirtualNetworkRule\"N\n\x12VirtualNetworkRule\x12\n\n\x02id\x18\x01 \x01(\t\x12,\n$ignore_missing_vnet_service_endpoint\x18\x02 \x01(\x08\"\x17\n\x06IPRule\x12\r\n\x05value\x18\x01 \x01(\t\"\x99\x01\n\x11\x41\x63\x63\x65ssPolicyEntry\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\x12\x11\n\tobject_id\x18\x02 \x01(\t\x12\x46\n\x0bpermissions\x18\x03 \x01(\x0b\x32\x31.oak9.tython.azure.microsoft_keyvault.Permissions\x12\x11\n\ttenant_id\x18\x04 \x01(\t\"S\n\x0bPermissions\x12\x14\n\x0c\x63\x65rtificates\x18\x01 \x03(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\x12\x0f\n\x07secrets\x18\x03 \x03(\t\x12\x0f\n\x07storage\x18\x04 \x03(\t\"\x96\x05\n%ManagedHSMsPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12S\n\x10private_endpoint\x18\x05 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_keyvault.MHSMPrivateEndpoint\x12z\n%private_link_service_connection_state\x18\x06 \x01(\x0b\x32K.oak9.tython.azure.microsoft_keyvault.MHSMPrivateLinkServiceConnectionState\x12\x1a\n\x12provisioning_state\x18\x07 \x01(\t\x12@\n\x03sku\x18\x08 \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_keyvault.ManagedHsmSku\x12\x45\n\x0bsystem_data\x18\t \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_keyvault.SystemData\x12\x63\n\x04tags\x18\n \x03(\x0b\x32U.oak9.tython.azure.microsoft_keyvault.ManagedHSMsPrivateEndpointConnections.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n%MHSMPrivateLinkServiceConnectionState\x12\x18\n\x10\x61\x63tions_required\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"#\n\x13MHSMPrivateEndpoint\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x87\x06\n\x0bManagedHSMs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x63reate_mode\x18\x04 \x01(\t\x12\x1f\n\x17\x65nable_purge_protection\x18\x05 \x01(\x08\x12\x1a\n\x12\x65nable_soft_delete\x18\x06 \x01(\x08\x12 \n\x18initial_admin_object_ids\x18\x07 \x03(\t\x12N\n\x0cnetwork_acls\x18\x08 \x01(\x0b\x32\x38.oak9.tython.azure.microsoft_keyvault.MHSMNetworkRuleSet\x12\x1d\n\x15public_network_access\x18\t \x01(\t\x12%\n\x1dsoft_delete_retention_in_days\x18\n \x01(\x05\x12\x11\n\ttenant_id\x18\x0b \x01(\t\x12@\n\x03sku\x18\x0c \x01(\x0b\x32\x33.oak9.tython.azure.microsoft_keyvault.ManagedHsmSku\x12\x45\n\x0bsystem_data\x18\r \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_keyvault.SystemData\x12I\n\x04tags\x18\x0e \x03(\x0b\x32;.oak9.tython.azure.microsoft_keyvault.ManagedHSMs.TagsEntry\x12\x80\x01\n+managed_h_s_ms_private_endpoint_connections\x18\x0f \x03(\x0b\x32K.oak9.tython.azure.microsoft_keyvault.ManagedHSMsPrivateEndpointConnections\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa0\x01\n\nSystemData\x12\x12\n\ncreated_at\x18\x01 \x01(\t\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x17\n\x0f\x63reated_by_type\x18\x03 \x01(\t\x12\x18\n\x10last_modified_at\x18\x04 \x01(\t\x12\x18\n\x10last_modified_by\x18\x05 \x01(\t\x12\x1d\n\x15last_modified_by_type\x18\x06 \x01(\t\"-\n\rManagedHsmSku\x12\x0e\n\x06\x66\x61mily\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xdd\x01\n\x12MHSMNetworkRuleSet\x12\x0e\n\x06\x62ypass\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x65\x66\x61ult_action\x18\x02 \x01(\t\x12\x42\n\x08ip_rules\x18\x03 \x03(\x0b\x32\x30.oak9.tython.azure.microsoft_keyvault.MHSMIPRule\x12[\n\x15virtual_network_rules\x18\x04 \x03(\x0b\x32<.oak9.tython.azure.microsoft_keyvault.MHSMVirtualNetworkRule\"$\n\x16MHSMVirtualNetworkRule\x12\n\n\x02id\x18\x01 \x01(\t\"\x1b\n\nMHSMIPRule\x12\r\n\x05value\x18\x01 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_keyvault_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VAULTSSECRETS_TAGSENTRY._options = None
  _VAULTSSECRETS_TAGSENTRY._serialized_options = b'8\001'
  _VAULTSKEYS_TAGSENTRY._options = None
  _VAULTSKEYS_TAGSENTRY._serialized_options = b'8\001'
  _VAULTS_TAGSENTRY._options = None
  _VAULTS_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDHSMSPRIVATEENDPOINTCONNECTIONS_TAGSENTRY._options = None
  _MANAGEDHSMSPRIVATEENDPOINTCONNECTIONS_TAGSENTRY._serialized_options = b'8\001'
  _MANAGEDHSMS_TAGSENTRY._options = None
  _MANAGEDHSMS_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_KEYVAULT._serialized_start=100
  _MICROSOFT_KEYVAULT._serialized_end=509
  _VAULTSCERTIFICATES._serialized_start=511
  _VAULTSCERTIFICATES._serialized_end=624
  _VAULTSSECRETS._serialized_start=627
  _VAULTSSECRETS._serialized_end=948
  _VAULTSSECRETS_TAGSENTRY._serialized_start=905
  _VAULTSSECRETS_TAGSENTRY._serialized_end=948
  _SECRETATTRIBUTES._serialized_start=950
  _SECRETATTRIBUTES._serialized_end=1011
  _VAULTSPRIVATEENDPOINTCONNECTIONS._serialized_start=1014
  _VAULTSPRIVATEENDPOINTCONNECTIONS._serialized_end=1362
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=1364
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=1462
  _PRIVATEENDPOINT._serialized_start=1464
  _PRIVATEENDPOINT._serialized_end=1495
  _VAULTSKEYS._serialized_start=1498
  _VAULTSKEYS._serialized_end=2000
  _VAULTSKEYS_TAGSENTRY._serialized_start=905
  _VAULTSKEYS_TAGSENTRY._serialized_end=948
  _ROTATIONPOLICY._serialized_start=2003
  _ROTATIONPOLICY._serialized_end=2186
  _LIFETIMEACTION._serialized_start=2189
  _LIFETIMEACTION._serialized_end=2331
  _TRIGGER._serialized_start=2333
  _TRIGGER._serialized_end=2397
  _ACTION._serialized_start=2399
  _ACTION._serialized_end=2421
  _KEYROTATIONPOLICYATTRIBUTES._serialized_start=2423
  _KEYROTATIONPOLICYATTRIBUTES._serialized_end=2473
  _KEYRELEASEPOLICY._serialized_start=2475
  _KEYRELEASEPOLICY._serialized_end=2529
  _KEYATTRIBUTES._serialized_start=2531
  _KEYATTRIBUTES._serialized_end=2609
  _VAULTSACCESSPOLICIES._serialized_start=2612
  _VAULTSACCESSPOLICIES._serialized_end=2787
  _VAULTS._serialized_start=2790
  _VAULTS._serialized_end=3696
  _VAULTS_TAGSENTRY._serialized_start=905
  _VAULTS_TAGSENTRY._serialized_end=948
  _SKU._serialized_start=3698
  _SKU._serialized_end=3733
  _NETWORKRULESET._serialized_start=3736
  _NETWORKRULESET._serialized_end=3945
  _VIRTUALNETWORKRULE._serialized_start=3947
  _VIRTUALNETWORKRULE._serialized_end=4025
  _IPRULE._serialized_start=4027
  _IPRULE._serialized_end=4050
  _ACCESSPOLICYENTRY._serialized_start=4053
  _ACCESSPOLICYENTRY._serialized_end=4206
  _PERMISSIONS._serialized_start=4208
  _PERMISSIONS._serialized_end=4291
  _MANAGEDHSMSPRIVATEENDPOINTCONNECTIONS._serialized_start=4294
  _MANAGEDHSMSPRIVATEENDPOINTCONNECTIONS._serialized_end=4956
  _MANAGEDHSMSPRIVATEENDPOINTCONNECTIONS_TAGSENTRY._serialized_start=905
  _MANAGEDHSMSPRIVATEENDPOINTCONNECTIONS_TAGSENTRY._serialized_end=948
  _MHSMPRIVATELINKSERVICECONNECTIONSTATE._serialized_start=4958
  _MHSMPRIVATELINKSERVICECONNECTIONSTATE._serialized_end=5060
  _MHSMPRIVATEENDPOINT._serialized_start=5062
  _MHSMPRIVATEENDPOINT._serialized_end=5097
  _MANAGEDHSMS._serialized_start=5100
  _MANAGEDHSMS._serialized_end=5875
  _MANAGEDHSMS_TAGSENTRY._serialized_start=905
  _MANAGEDHSMS_TAGSENTRY._serialized_end=948
  _SYSTEMDATA._serialized_start=5878
  _SYSTEMDATA._serialized_end=6038
  _MANAGEDHSMSKU._serialized_start=6040
  _MANAGEDHSMSKU._serialized_end=6085
  _MHSMNETWORKRULESET._serialized_start=6088
  _MHSMNETWORKRULESET._serialized_end=6309
  _MHSMVIRTUALNETWORKRULE._serialized_start=6311
  _MHSMVIRTUALNETWORKRULE._serialized_end=6347
  _MHSMIPRULE._serialized_start=6349
  _MHSMIPRULE._serialized_end=6376
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_networkmanager.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61ws/aws_networkmanager.proto\x12\x1eoak9.tython.aws.networkmanager\x1a\x13shared/shared.proto\"\xb2\x01\n\x1a\x43ustomerGatewayAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11global_network_id\x18\x02 \x01(\t\x12\x1c\n\x14\x63ustomer_gateway_arn\x18\x03 \x01(\t\x12\x11\n\tdevice_id\x18\x04 \x01(\t\x12\x0f\n\x07link_id\x18\x05 \x01(\t\"\x86\x04\n\x0eNetworkManager\x12`\n\x1c\x63ustomer_gateway_association\x18\x01 \x03(\x0b\x32:.oak9.tython.aws.networkmanager.CustomerGatewayAssociation\x12\x36\n\x06\x64\x65vice\x18\x02 \x03(\x0b\x32&.oak9.tython.aws.networkmanager.Device\x12\x45\n\x0eglobal_network\x18\x03 \x03(\x0b\x32-.oak9.tython.aws.networkmanager.GlobalNetwork\x12\x32\n\x04link\x18\x04 \x03(\x0b\x32$.oak9.tython.aws.networkmanager.Link\x12I\n\x10link_association\x18\x05 \x03(\x0b\x32/.oak9.tython.aws.networkmanager.LinkAssociation\x12\x32\n\x04site\x18\x06 \x03(\x0b\x32$.oak9.tython.aws.networkmanager.Site\x12`\n\x1ctransit_gateway_registration\x18\x07 \x03(\x0b\x32:.oak9.tython.aws.networkmanager.TransitGatewayRegistration\"\x7f\n\x0e\x44\x65viceLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x10\n\x08latitude\x18\x03 \x01(\t\x12\x11\n\tlongitude\x18\x04 \x01(\t\"\xf5\x02\n\x06\x44\x65vice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12>\n\x04tags\x18\x03 \x03(\x0b\x32\x30.oak9.tython.aws.networkmanager.Device.TagsEntry\x12\x19\n\x11global_network_id\x18\x04 \x01(\t\x12@\n\x08location\x18\x05 \x01(\x0b\x32..oak9.tython.aws.networkmanager.DeviceLocation\x12\r\n\x05model\x18\x06 \x01(\t\x12\x15\n\rserial_number\x18\x07 \x01(\t\x12\x0f\n\x07site_id\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\x12\x0e\n\x06vendor\x18\n \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd1\x01\n\rGlobalNetwork\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x45\n\x04tags\x18\x03 \x03(\x0b\x32\x37.oak9.tython.aws.networkmanager.GlobalNetwork.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"v\n\rLinkBandwidth\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x64ownload_speed\x18\x02 \x01(\x05\x12\x14\n\x0cupload_speed\x18\x03 \x01(\x05\"\xcd\x02\n\x04Link\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11global_network_id\x18\x02 \x01(\t\x12\x0f\n\x07site_id\x18\x03 \x01(\t\x12@\n\tbandwidth\x18\x04 \x01(\x0b\x32-.oak9.tython.aws.networkmanager.LinkBandwidth\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12<\n\x04tags\x18\x07 \x03(\x0b\x32..oak9.tython.aws.networkmanager.Link.TagsEntry\x12\x0c\n\x04type\x18\x08 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x89\x01\n\x0fLinkAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11global_network_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\x12\x0f\n\x07link_id\x18\x04 \x01(\t\"}\n\x0cSiteLocation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x10\n\x08latitude\x18\x03 \x01(\t\x12\x11\n\tlongitude\x18\x04 \x01(\t\"\x9a\x02\n\x04Site\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12<\n\x04tags\x18\x03 \x03(\x0b\x32..oak9.tython.aws.networkmanager.Site.TagsEntry\x12\x19\n\x11global_network_id\x18\x04 \x01(\t\x12>\n\x08location\x18\x05 \x01(\x0b\x32,.oak9.tython.aws.networkmanager.SiteLocation\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n\x1aTransitGatewayRegistration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11global_network_id\x18\x02 \x01(\t\x12\x1b\n\x13transit_gateway_arn\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_networkmanager_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DEVICE_TAGSENTRY._options = None
  _DEVICE_TAGSENTRY._serialized_options = b'8\001'
  _GLOBALNETWORK_TAGSENTRY._options = None
  _GLOBALNETWORK_TAGSENTRY._serialized_options = b'8\001'
  _LINK_TAGSENTRY._options = None
  _LINK_TAGSENTRY._serialized_options = b'8\001'
  _SITE_TAGSENTRY._options = None
  _SITE_TAGSENTRY._serialized_options = b'8\001'
  _CUSTOMERGATEWAYASSOCIATION._serialized_start=86
  _CUSTOMERGATEWAYASSOCIATION._serialized_end=264
  _NETWORKMANAGER._serialized_start=267
  _NETWORKMANAGER._serialized_end=785
  _DEVICELOCATION._serialized_start=787
  _DEVICELOCATION._serialized_end=914
  _DEVICE._serialized_start=917
  _DEVICE._serialized_end=1290
  _DEVICE_TAGSENTRY._serialized_start=1247
  _DEVICE_TAGSENTRY._serialized_end=1290
  _GLOBALNETWORK._serialized_start=1293
  _GLOBALNETWORK._serialized_end=1502
  _GLOBALNETWORK_TAGSENTRY._serialized_start=1247
  _GLOBALNETWORK_TAGSENTRY._serialized_end=1290
  _LINKBANDWIDTH._serialized_start=1504
  _LINKBANDWIDTH._serialized_end=1622
  _LINK._serialized_start=1625
  _LINK._serialized_end=1958
  _LINK_TAGSENTRY._serialized_start=1247
  _LINK_TAGSENTRY._serialized_end=1290
  _LINKASSOCIATION._serialized_start=1961
  _LINKASSOCIATION._serialized_end=2098
  _SITELOCATION._serialized_start=2100
  _SITELOCATION._serialized_end=2225
  _SITE._serialized_start=2228
  _SITE._serialized_end=2510
  _SITE_TAGSENTRY._serialized_start=1247
  _SITE_TAGSENTRY._serialized_end=1290
  _TRANSITGATEWAYREGISTRATION._serialized_start=2513
  _TRANSITGATEWAYREGISTRATION._serialized_end=2654
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Application(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    COMPUTE_PLATFORM_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    application_name: builtins.str
    compute_platform: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        application_name: builtins.str = ...,
        compute_platform: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_name", b"application_name", "compute_platform", b"compute_platform", "resource_info", b"resource_info"]) -> None: ...

global___Application = Application

@typing_extensions.final
class CodeDeploy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    DEPLOYMENT_CONFIG_FIELD_NUMBER: builtins.int
    DEPLOYMENT_GROUP_FIELD_NUMBER: builtins.int
    @property
    def application(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Application]: ...
    @property
    def deployment_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentConfig]: ...
    @property
    def deployment_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroup]: ...
    def __init__(
        self,
        *,
        application: collections.abc.Iterable[global___Application] | None = ...,
        deployment_config: collections.abc.Iterable[global___DeploymentConfig] | None = ...,
        deployment_group: collections.abc.Iterable[global___DeploymentGroup] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "deployment_config", b"deployment_config", "deployment_group", b"deployment_group"]) -> None: ...

global___CodeDeploy = CodeDeploy

@typing_extensions.final
class DeploymentConfigMinimumHealthyHosts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    value: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___DeploymentConfigMinimumHealthyHosts = DeploymentConfigMinimumHealthyHosts

@typing_extensions.final
class DeploymentConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEPLOYMENT_CONFIG_NAME_FIELD_NUMBER: builtins.int
    MINIMUM_HEALTHY_HOSTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    deployment_config_name: builtins.str
    @property
    def minimum_healthy_hosts(self) -> global___DeploymentConfigMinimumHealthyHosts: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        deployment_config_name: builtins.str = ...,
        minimum_healthy_hosts: global___DeploymentConfigMinimumHealthyHosts | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["minimum_healthy_hosts", b"minimum_healthy_hosts", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_config_name", b"deployment_config_name", "minimum_healthy_hosts", b"minimum_healthy_hosts", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentConfig = DeploymentConfig

@typing_extensions.final
class DeploymentGroupAlarm(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupAlarm = DeploymentGroupAlarm

@typing_extensions.final
class DeploymentGroupAlarmConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARMS_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    IGNORE_POLL_ALARM_FAILURE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def alarms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupAlarm]: ...
    enabled: builtins.bool
    ignore_poll_alarm_failure: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarms: collections.abc.Iterable[global___DeploymentGroupAlarm] | None = ...,
        enabled: builtins.bool = ...,
        ignore_poll_alarm_failure: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarms", b"alarms", "enabled", b"enabled", "ignore_poll_alarm_failure", b"ignore_poll_alarm_failure", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupAlarmConfiguration = DeploymentGroupAlarmConfiguration

@typing_extensions.final
class DeploymentGroupAutoRollbackConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    EVENTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    enabled: builtins.bool
    @property
    def events(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        enabled: builtins.bool = ...,
        events: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["enabled", b"enabled", "events", b"events", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupAutoRollbackConfiguration = DeploymentGroupAutoRollbackConfiguration

@typing_extensions.final
class DeploymentGroupGitHubLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMMIT_ID_FIELD_NUMBER: builtins.int
    REPOSITORY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    commit_id: builtins.str
    repository: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        commit_id: builtins.str = ...,
        repository: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["commit_id", b"commit_id", "repository", b"repository", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupGitHubLocation = DeploymentGroupGitHubLocation

@typing_extensions.final
class DeploymentGroupS3Location(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUCKET_FIELD_NUMBER: builtins.int
    BUNDLE_TYPE_FIELD_NUMBER: builtins.int
    E_TAG_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    bucket: builtins.str
    bundle_type: builtins.str
    e_tag: builtins.str
    key: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        bucket: builtins.str = ...,
        bundle_type: builtins.str = ...,
        e_tag: builtins.str = ...,
        key: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bucket", b"bucket", "bundle_type", b"bundle_type", "e_tag", b"e_tag", "key", b"key", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___DeploymentGroupS3Location = DeploymentGroupS3Location

@typing_extensions.final
class DeploymentGroupRevisionLocation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    GIT_HUB_LOCATION_FIELD_NUMBER: builtins.int
    REVISION_TYPE_FIELD_NUMBER: builtins.int
    S3_LOCATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def git_hub_location(self) -> global___DeploymentGroupGitHubLocation: ...
    revision_type: builtins.str
    @property
    def s3_location(self) -> global___DeploymentGroupS3Location: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        git_hub_location: global___DeploymentGroupGitHubLocation | None = ...,
        revision_type: builtins.str = ...,
        s3_location: global___DeploymentGroupS3Location | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["git_hub_location", b"git_hub_location", "resource_info", b"resource_info", "s3_location", b"s3_location"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["git_hub_location", b"git_hub_location", "resource_info", b"resource_info", "revision_type", b"revision_type", "s3_location", b"s3_location"]) -> None: ...

global___DeploymentGroupRevisionLocation = DeploymentGroupRevisionLocation

@typing_extensions.final
class DeploymentGroupDeployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    IGNORE_APPLICATION_STOP_FAILURES_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    ignore_application_stop_failures: builtins.bool
    @property
    def revision(self) -> global___DeploymentGroupRevisionLocation: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        ignore_application_stop_failures: builtins.bool = ...,
        revision: global___DeploymentGroupRevisionLocation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "revision", b"revision"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "ignore_application_stop_failures", b"ignore_application_stop_failures", "resource_info", b"resource_info", "revision", b"revision"]) -> None: ...

global___DeploymentGroupDeployment = DeploymentGroupDeployment

@typing_extensions.final
class DeploymentGroupDeploymentStyle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DEPLOYMENT_OPTION_FIELD_NUMBER: builtins.int
    DEPLOYMENT_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    deployment_option: builtins.str
    deployment_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        deployment_option: builtins.str = ...,
        deployment_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deployment_option", b"deployment_option", "deployment_type", b"deployment_type", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupDeploymentStyle = DeploymentGroupDeploymentStyle

@typing_extensions.final
class DeploymentGroupEC2TagFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___DeploymentGroupEC2TagFilter = DeploymentGroupEC2TagFilter

@typing_extensions.final
class DeploymentGroupEC2TagSetListObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EC2_TAG_GROUP_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def ec2_tag_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupEC2TagFilter]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ec2_tag_group: collections.abc.Iterable[global___DeploymentGroupEC2TagFilter] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ec2_tag_group", b"ec2_tag_group", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupEC2TagSetListObject = DeploymentGroupEC2TagSetListObject

@typing_extensions.final
class DeploymentGroupEC2TagSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    EC2_TAG_SET_LIST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def ec2_tag_set_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupEC2TagSetListObject]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ec2_tag_set_list: collections.abc.Iterable[global___DeploymentGroupEC2TagSetListObject] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ec2_tag_set_list", b"ec2_tag_set_list", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupEC2TagSet = DeploymentGroupEC2TagSet

@typing_extensions.final
class DeploymentGroupELBInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupELBInfo = DeploymentGroupELBInfo

@typing_extensions.final
class DeploymentGroupTargetGroupInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupTargetGroupInfo = DeploymentGroupTargetGroupInfo

@typing_extensions.final
class DeploymentGroupLoadBalancerInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ELB_INFO_LIST_FIELD_NUMBER: builtins.int
    TARGET_GROUP_INFO_LIST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def elb_info_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupELBInfo]: ...
    @property
    def target_group_info_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupTargetGroupInfo]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        elb_info_list: collections.abc.Iterable[global___DeploymentGroupELBInfo] | None = ...,
        target_group_info_list: collections.abc.Iterable[global___DeploymentGroupTargetGroupInfo] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["elb_info_list", b"elb_info_list", "resource_info", b"resource_info", "target_group_info_list", b"target_group_info_list"]) -> None: ...

global___DeploymentGroupLoadBalancerInfo = DeploymentGroupLoadBalancerInfo

@typing_extensions.final
class DeploymentGroupTagFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___DeploymentGroupTagFilter = DeploymentGroupTagFilter

@typing_extensions.final
class DeploymentGroupOnPremisesTagSetListObject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ON_PREMISES_TAG_GROUP_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def on_premises_tag_group(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupTagFilter]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        on_premises_tag_group: collections.abc.Iterable[global___DeploymentGroupTagFilter] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["on_premises_tag_group", b"on_premises_tag_group", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupOnPremisesTagSetListObject = DeploymentGroupOnPremisesTagSetListObject

@typing_extensions.final
class DeploymentGroupOnPremisesTagSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ON_PREMISES_TAG_SET_LIST_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def on_premises_tag_set_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupOnPremisesTagSetListObject]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        on_premises_tag_set_list: collections.abc.Iterable[global___DeploymentGroupOnPremisesTagSetListObject] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["on_premises_tag_set_list", b"on_premises_tag_set_list", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentGroupOnPremisesTagSet = DeploymentGroupOnPremisesTagSet

@typing_extensions.final
class DeploymentGroupTriggerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TRIGGER_EVENTS_FIELD_NUMBER: builtins.int
    TRIGGER_NAME_FIELD_NUMBER: builtins.int
    TRIGGER_TARGET_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def trigger_events(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    trigger_name: builtins.str
    trigger_target_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        trigger_events: collections.abc.Iterable[builtins.str] | None = ...,
        trigger_name: builtins.str = ...,
        trigger_target_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "trigger_events", b"trigger_events", "trigger_name", b"trigger_name", "trigger_target_arn", b"trigger_target_arn"]) -> None: ...

global___DeploymentGroupTriggerConfig = DeploymentGroupTriggerConfig

@typing_extensions.final
class DeploymentGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ALARM_CONFIGURATION_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    AUTO_ROLLBACK_CONFIGURATION_FIELD_NUMBER: builtins.int
    AUTO_SCALING_GROUPS_FIELD_NUMBER: builtins.int
    DEPLOYMENT_FIELD_NUMBER: builtins.int
    DEPLOYMENT_CONFIG_NAME_FIELD_NUMBER: builtins.int
    DEPLOYMENT_GROUP_NAME_FIELD_NUMBER: builtins.int
    DEPLOYMENT_STYLE_FIELD_NUMBER: builtins.int
    EC2_TAG_FILTERS_FIELD_NUMBER: builtins.int
    EC2_TAG_SET_FIELD_NUMBER: builtins.int
    LOAD_BALANCER_INFO_FIELD_NUMBER: builtins.int
    ON_PREMISES_INSTANCE_TAG_FILTERS_FIELD_NUMBER: builtins.int
    ON_PREMISES_TAG_SET_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_ARN_FIELD_NUMBER: builtins.int
    TRIGGER_CONFIGURATIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def alarm_configuration(self) -> global___DeploymentGroupAlarmConfiguration: ...
    application_name: builtins.str
    @property
    def auto_rollback_configuration(self) -> global___DeploymentGroupAutoRollbackConfiguration: ...
    @property
    def auto_scaling_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def deployment(self) -> global___DeploymentGroupDeployment: ...
    deployment_config_name: builtins.str
    deployment_group_name: builtins.str
    @property
    def deployment_style(self) -> global___DeploymentGroupDeploymentStyle: ...
    @property
    def ec2_tag_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupEC2TagFilter]: ...
    @property
    def ec2_tag_set(self) -> global___DeploymentGroupEC2TagSet: ...
    @property
    def load_balancer_info(self) -> global___DeploymentGroupLoadBalancerInfo: ...
    @property
    def on_premises_instance_tag_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupTagFilter]: ...
    @property
    def on_premises_tag_set(self) -> global___DeploymentGroupOnPremisesTagSet: ...
    service_role_arn: builtins.str
    @property
    def trigger_configurations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentGroupTriggerConfig]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        alarm_configuration: global___DeploymentGroupAlarmConfiguration | None = ...,
        application_name: builtins.str = ...,
        auto_rollback_configuration: global___DeploymentGroupAutoRollbackConfiguration | None = ...,
        auto_scaling_groups: collections.abc.Iterable[builtins.str] | None = ...,
        deployment: global___DeploymentGroupDeployment | None = ...,
        deployment_config_name: builtins.str = ...,
        deployment_group_name: builtins.str = ...,
        deployment_style: global___DeploymentGroupDeploymentStyle | None = ...,
        ec2_tag_filters: collections.abc.Iterable[global___DeploymentGroupEC2TagFilter] | None = ...,
        ec2_tag_set: global___DeploymentGroupEC2TagSet | None = ...,
        load_balancer_info: global___DeploymentGroupLoadBalancerInfo | None = ...,
        on_premises_instance_tag_filters: collections.abc.Iterable[global___DeploymentGroupTagFilter] | None = ...,
        on_premises_tag_set: global___DeploymentGroupOnPremisesTagSet | None = ...,
        service_role_arn: builtins.str = ...,
        trigger_configurations: collections.abc.Iterable[global___DeploymentGroupTriggerConfig] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["alarm_configuration", b"alarm_configuration", "auto_rollback_configuration", b"auto_rollback_configuration", "deployment", b"deployment", "deployment_style", b"deployment_style", "ec2_tag_set", b"ec2_tag_set", "load_balancer_info", b"load_balancer_info", "on_premises_tag_set", b"on_premises_tag_set", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["alarm_configuration", b"alarm_configuration", "application_name", b"application_name", "auto_rollback_configuration", b"auto_rollback_configuration", "auto_scaling_groups", b"auto_scaling_groups", "deployment", b"deployment", "deployment_config_name", b"deployment_config_name", "deployment_group_name", b"deployment_group_name", "deployment_style", b"deployment_style", "ec2_tag_filters", b"ec2_tag_filters", "ec2_tag_set", b"ec2_tag_set", "load_balancer_info", b"load_balancer_info", "on_premises_instance_tag_filters", b"on_premises_instance_tag_filters", "on_premises_tag_set", b"on_premises_tag_set", "resource_info", b"resource_info", "service_role_arn", b"service_role_arn", "trigger_configurations", b"trigger_configurations"]) -> None: ...

global___DeploymentGroup = DeploymentGroup



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import gcp.gcp_certificate_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleCertificateManager(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_MANAGER_CERTIFICATE_FIELD_NUMBER: builtins.int
    CERTIFICATE_MANAGER_CERTIFICATE_MAP_FIELD_NUMBER: builtins.int
    CERTIFICATE_MANAGER_CERTIFICATE_MAP_ENTRY_FIELD_NUMBER: builtins.int
    CERTIFICATE_MANAGER_DNS_AUTHORIZATION_FIELD_NUMBER: builtins.int
    @property
    def certificate_manager_certificate(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_certificate_pb2.CertificateManagerCertificate]: ...
    @property
    def certificate_manager_certificate_map(self) -> gcp.gcp_certificate_pb2.CertificateManagerCertificateMap: ...
    @property
    def certificate_manager_certificate_map_entry(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_certificate_pb2.CertificateManagerCertificateMapEntry]: ...
    @property
    def certificate_manager_dns_authorization(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[gcp.gcp_certificate_pb2.CertificateManagerDnsAuthorization]: ...
    def __init__(
        self,
        *,
        certificate_manager_certificate: collections.abc.Iterable[gcp.gcp_certificate_pb2.CertificateManagerCertificate] | None = ...,
        certificate_manager_certificate_map: gcp.gcp_certificate_pb2.CertificateManagerCertificateMap | None = ...,
        certificate_manager_certificate_map_entry: collections.abc.Iterable[gcp.gcp_certificate_pb2.CertificateManagerCertificateMapEntry] | None = ...,
        certificate_manager_dns_authorization: collections.abc.Iterable[gcp.gcp_certificate_pb2.CertificateManagerDnsAuthorization] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["certificate_manager_certificate_map", b"certificate_manager_certificate_map"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_manager_certificate", b"certificate_manager_certificate", "certificate_manager_certificate_map", b"certificate_manager_certificate_map", "certificate_manager_certificate_map_entry", b"certificate_manager_certificate_map_entry", "certificate_manager_dns_authorization", b"certificate_manager_dns_authorization"]) -> None: ...

global___GoogleCertificateManager = GoogleCertificateManager



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_wafregional.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61ws/aws_wafregional.proto\x12\x1boak9.tython.aws.wafregional\x1a\x13shared/shared.proto\"a\n\x18\x42yteMatchSetFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"\x95\x02\n\x1a\x42yteMatchSetByteMatchTuple\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rtarget_string\x18\x02 \x01(\t\x12\x1c\n\x14target_string_base64\x18\x03 \x01(\t\x12\x1d\n\x15positional_constraint\x18\x04 \x01(\t\x12\x1b\n\x13text_transformation\x18\x05 \x01(\t\x12M\n\x0e\x66ield_to_match\x18\x06 \x01(\x0b\x32\x35.oak9.tython.aws.wafregional.ByteMatchSetFieldToMatch\"\xa9\x01\n\x0c\x42yteMatchSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x11\x62yte_match_tuples\x18\x02 \x03(\x0b\x32\x37.oak9.tython.aws.wafregional.ByteMatchSetByteMatchTuple\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xed\x05\n\x0bWAFRegional\x12\x41\n\x0e\x62yte_match_set\x18\x01 \x03(\x0b\x32).oak9.tython.aws.wafregional.ByteMatchSet\x12?\n\rgeo_match_set\x18\x02 \x03(\x0b\x32(.oak9.tython.aws.wafregional.GeoMatchSet\x12\x32\n\x06ip_set\x18\x03 \x03(\x0b\x32\".oak9.tython.aws.wafregional.IPSet\x12\x43\n\x0frate_based_rule\x18\x04 \x03(\x0b\x32*.oak9.tython.aws.wafregional.RateBasedRule\x12G\n\x11regex_pattern_set\x18\x05 \x03(\x0b\x32,.oak9.tython.aws.wafregional.RegexPatternSet\x12/\n\x04rule\x18\x06 \x03(\x0b\x32!.oak9.tython.aws.wafregional.Rule\x12K\n\x13size_constraint_set\x18\x07 \x03(\x0b\x32..oak9.tython.aws.wafregional.SizeConstraintSet\x12R\n\x17sql_injection_match_set\x18\x08 \x03(\x0b\x32\x31.oak9.tython.aws.wafregional.SqlInjectionMatchSet\x12\x36\n\tweb_a_c_l\x18\t \x03(\x0b\x32#.oak9.tython.aws.wafregional.WebACL\x12M\n\x15web_a_c_l_association\x18\n \x03(\x0b\x32..oak9.tython.aws.wafregional.WebACLAssociation\x12?\n\rxss_match_set\x18\x0b \x03(\x0b\x32(.oak9.tython.aws.wafregional.XssMatchSet\"g\n\x1dGeoMatchSetGeoMatchConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\"\xaf\x01\n\x0bGeoMatchSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x15geo_match_constraints\x18\x02 \x03(\x0b\x32:.oak9.tython.aws.wafregional.GeoMatchSetGeoMatchConstraint\x12\x0c\n\x04name\x18\x03 \x01(\t\"^\n\x14IPSetIPSetDescriptor\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\"\x9d\x01\n\x05IPSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12M\n\x12ip_set_descriptors\x18\x02 \x03(\x0b\x32\x31.oak9.tython.aws.wafregional.IPSetIPSetDescriptor\x12\x0c\n\x04name\x18\x03 \x01(\t\"s\n\x16RateBasedRulePredicate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x64\x61ta_id\x18\x02 \x01(\t\x12\x0f\n\x07negated\x18\x03 \x01(\x08\"\xe0\x01\n\rRateBasedRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmetric_name\x18\x02 \x01(\t\x12\x12\n\nrate_limit\x18\x03 \x01(\x05\x12M\n\x10match_predicates\x18\x04 \x03(\x0b\x32\x33.oak9.tython.aws.wafregional.RateBasedRulePredicate\x12\x10\n\x08rate_key\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\"w\n\x0fRegexPatternSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15regex_pattern_strings\x18\x02 \x03(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"j\n\rRulePredicate\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x64\x61ta_id\x18\x02 \x01(\t\x12\x0f\n\x07negated\x18\x03 \x01(\x08\"\xa2\x01\n\x04Rule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmetric_name\x18\x02 \x01(\t\x12>\n\npredicates\x18\x03 \x03(\x0b\x32*.oak9.tython.aws.wafregional.RulePredicate\x12\x0c\n\x04name\x18\x04 \x01(\t\"f\n\x1dSizeConstraintSetFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"\xf6\x01\n\x1fSizeConstraintSetSizeConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63omparison_operator\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x05\x12\x1b\n\x13text_transformation\x18\x04 \x01(\t\x12R\n\x0e\x66ield_to_match\x18\x05 \x01(\x0b\x32:.oak9.tython.aws.wafregional.SizeConstraintSetFieldToMatch\"\xb2\x01\n\x11SizeConstraintSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12V\n\x10size_constraints\x18\x02 \x03(\x0b\x32<.oak9.tython.aws.wafregional.SizeConstraintSetSizeConstraint\x12\x0c\n\x04name\x18\x03 \x01(\t\"i\n SqlInjectionMatchSetFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"\xd9\x01\n*SqlInjectionMatchSetSqlInjectionMatchTuple\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13text_transformation\x18\x02 \x01(\t\x12U\n\x0e\x66ield_to_match\x18\x03 \x01(\x0b\x32=.oak9.tython.aws.wafregional.SqlInjectionMatchSetFieldToMatch\"\xca\x01\n\x14SqlInjectionMatchSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12k\n\x1asql_injection_match_tuples\x18\x02 \x03(\x0b\x32G.oak9.tython.aws.wafregional.SqlInjectionMatchSetSqlInjectionMatchTuple\x12\x0c\n\x04name\x18\x03 \x01(\t\"G\n\x0cWebACLAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa3\x01\n\nWebACLRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x39\n\x06\x61\x63tion\x18\x02 \x01(\x0b\x32).oak9.tython.aws.wafregional.WebACLAction\x12\x10\n\x08priority\x18\x03 \x01(\x05\x12\x0f\n\x07rule_id\x18\x04 \x01(\t\"\xdf\x01\n\x06WebACL\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bmetric_name\x18\x02 \x01(\t\x12\x41\n\x0e\x64\x65\x66\x61ult_action\x18\x03 \x01(\x0b\x32).oak9.tython.aws.wafregional.WebACLAction\x12\x36\n\x05rules\x18\x04 \x03(\x0b\x32\'.oak9.tython.aws.wafregional.WebACLRule\x12\x0c\n\x04name\x18\x05 \x01(\t\"x\n\x11WebACLAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cresource_arn\x18\x02 \x01(\t\x12\x14\n\x0cweb_a_c_l_id\x18\x03 \x01(\t\"`\n\x17XssMatchSetFieldToMatch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"\xbe\x01\n\x18XssMatchSetXssMatchTuple\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13text_transformation\x18\x02 \x01(\t\x12L\n\x0e\x66ield_to_match\x18\x03 \x01(\x0b\x32\x34.oak9.tython.aws.wafregional.XssMatchSetFieldToMatch\"\xa5\x01\n\x0bXssMatchSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12O\n\x10xss_match_tuples\x18\x02 \x03(\x0b\x32\x35.oak9.tython.aws.wafregional.XssMatchSetXssMatchTuple\x12\x0c\n\x04name\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_wafregional_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BYTEMATCHSETFIELDTOMATCH._serialized_start=79
  _BYTEMATCHSETFIELDTOMATCH._serialized_end=176
  _BYTEMATCHSETBYTEMATCHTUPLE._serialized_start=179
  _BYTEMATCHSETBYTEMATCHTUPLE._serialized_end=456
  _BYTEMATCHSET._serialized_start=459
  _BYTEMATCHSET._serialized_end=628
  _WAFREGIONAL._serialized_start=631
  _WAFREGIONAL._serialized_end=1380
  _GEOMATCHSETGEOMATCHCONSTRAINT._serialized_start=1382
  _GEOMATCHSETGEOMATCHCONSTRAINT._serialized_end=1485
  _GEOMATCHSET._serialized_start=1488
  _GEOMATCHSET._serialized_end=1663
  _IPSETIPSETDESCRIPTOR._serialized_start=1665
  _IPSETIPSETDESCRIPTOR._serialized_end=1759
  _IPSET._serialized_start=1762
  _IPSET._serialized_end=1919
  _RATEBASEDRULEPREDICATE._serialized_start=1921
  _RATEBASEDRULEPREDICATE._serialized_end=2036
  _RATEBASEDRULE._serialized_start=2039
  _RATEBASEDRULE._serialized_end=2263
  _REGEXPATTERNSET._serialized_start=2265
  _REGEXPATTERNSET._serialized_end=2384
  _RULEPREDICATE._serialized_start=2386
  _RULEPREDICATE._serialized_end=2492
  _RULE._serialized_start=2495
  _RULE._serialized_end=2657
  _SIZECONSTRAINTSETFIELDTOMATCH._serialized_start=2659
  _SIZECONSTRAINTSETFIELDTOMATCH._serialized_end=2761
  _SIZECONSTRAINTSETSIZECONSTRAINT._serialized_start=2764
  _SIZECONSTRAINTSETSIZECONSTRAINT._serialized_end=3010
  _SIZECONSTRAINTSET._serialized_start=3013
  _SIZECONSTRAINTSET._serialized_end=3191
  _SQLINJECTIONMATCHSETFIELDTOMATCH._serialized_start=3193
  _SQLINJECTIONMATCHSETFIELDTOMATCH._serialized_end=3298
  _SQLINJECTIONMATCHSETSQLINJECTIONMATCHTUPLE._serialized_start=3301
  _SQLINJECTIONMATCHSETSQLINJECTIONMATCHTUPLE._serialized_end=3518
  _SQLINJECTIONMATCHSET._serialized_start=3521
  _SQLINJECTIONMATCHSET._serialized_end=3723
  _WEBACLACTION._serialized_start=3725
  _WEBACLACTION._serialized_end=3796
  _WEBACLRULE._serialized_start=3799
  _WEBACLRULE._serialized_end=3962
  _WEBACL._serialized_start=3965
  _WEBACL._serialized_end=4188
  _WEBACLASSOCIATION._serialized_start=4190
  _WEBACLASSOCIATION._serialized_end=4310
  _XSSMATCHSETFIELDTOMATCH._serialized_start=4312
  _XSSMATCHSETFIELDTOMATCH._serialized_end=4408
  _XSSMATCHSETXSSMATCHTUPLE._serialized_start=4411
  _XSSMATCHSETXSSMATCHTUPLE._serialized_end=4601
  _XSSMATCHSET._serialized_start=4604
  _XSSMATCHSET._serialized_end=4769
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Subnet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ASSIGN_IPV6_ADDRESS_ON_CREATION_FIELD_NUMBER: builtins.int
    AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    CIDR_BLOCK_FIELD_NUMBER: builtins.int
    IPV6_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    MAP_PUBLIC_IP_ON_LAUNCH_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    assign_ipv6_address_on_creation: builtins.bool
    availability_zone: builtins.str
    cidr_block: builtins.str
    ipv6_cidr_block: builtins.str
    map_public_ip_on_launch: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    vpc_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        assign_ipv6_address_on_creation: builtins.bool = ...,
        availability_zone: builtins.str = ...,
        cidr_block: builtins.str = ...,
        ipv6_cidr_block: builtins.str = ...,
        map_public_ip_on_launch: builtins.bool = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        vpc_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assign_ipv6_address_on_creation", b"assign_ipv6_address_on_creation", "availability_zone", b"availability_zone", "cidr_block", b"cidr_block", "ipv6_cidr_block", b"ipv6_cidr_block", "map_public_ip_on_launch", b"map_public_ip_on_launch", "resource_info", b"resource_info", "tags", b"tags", "vpc_id", b"vpc_id"]) -> None: ...

global___Subnet = Subnet

@typing_extensions.final
class EC2_Subnet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBNET_FIELD_NUMBER: builtins.int
    SUBNET_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    SUBNET_NETWORK_ACL_ASSOCIATION_FIELD_NUMBER: builtins.int
    SUBNET_ROUTE_TABLE_ASSOCIATION_FIELD_NUMBER: builtins.int
    @property
    def subnet(self) -> global___Subnet: ...
    @property
    def subnet_cidr_block(self) -> global___SubnetCidrBlock: ...
    @property
    def subnet_network_acl_association(self) -> global___SubnetNetworkAclAssociation: ...
    @property
    def subnet_route_table_association(self) -> global___SubnetRouteTableAssociation: ...
    def __init__(
        self,
        *,
        subnet: global___Subnet | None = ...,
        subnet_cidr_block: global___SubnetCidrBlock | None = ...,
        subnet_network_acl_association: global___SubnetNetworkAclAssociation | None = ...,
        subnet_route_table_association: global___SubnetRouteTableAssociation | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subnet", b"subnet", "subnet_cidr_block", b"subnet_cidr_block", "subnet_network_acl_association", b"subnet_network_acl_association", "subnet_route_table_association", b"subnet_route_table_association"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["subnet", b"subnet", "subnet_cidr_block", b"subnet_cidr_block", "subnet_network_acl_association", b"subnet_network_acl_association", "subnet_route_table_association", b"subnet_route_table_association"]) -> None: ...

global___EC2_Subnet = EC2_Subnet

@typing_extensions.final
class SubnetCidrBlock(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IPV6_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ipv6_cidr_block: builtins.str
    subnet_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ipv6_cidr_block: builtins.str = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ipv6_cidr_block", b"ipv6_cidr_block", "resource_info", b"resource_info", "subnet_id", b"subnet_id"]) -> None: ...

global___SubnetCidrBlock = SubnetCidrBlock

@typing_extensions.final
class SubnetNetworkAclAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NETWORK_ACL_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    network_acl_id: builtins.str
    subnet_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        network_acl_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_acl_id", b"network_acl_id", "resource_info", b"resource_info", "subnet_id", b"subnet_id"]) -> None: ...

global___SubnetNetworkAclAssociation = SubnetNetworkAclAssociation

@typing_extensions.final
class SubnetRouteTableAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ROUTE_TABLE_ID_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    route_table_id: builtins.str
    subnet_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        route_table_id: builtins.str = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "route_table_id", b"route_table_id", "subnet_id", b"subnet_id"]) -> None: ...

global___SubnetRouteTableAssociation = SubnetRouteTableAssociation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class BudgetSubscriber(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SUBSCRIPTION_TYPE_FIELD_NUMBER: builtins.int
    ADDRESS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    subscription_type: builtins.str
    address: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        subscription_type: builtins.str = ...,
        address: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "resource_info", b"resource_info", "subscription_type", b"subscription_type"]) -> None: ...

global___BudgetSubscriber = BudgetSubscriber

@typing_extensions.final
class BudgetNotification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COMPARISON_OPERATOR_FIELD_NUMBER: builtins.int
    NOTIFICATION_TYPE_FIELD_NUMBER: builtins.int
    THRESHOLD_FIELD_NUMBER: builtins.int
    THRESHOLD_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    comparison_operator: builtins.str
    notification_type: builtins.str
    threshold: builtins.float
    threshold_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        comparison_operator: builtins.str = ...,
        notification_type: builtins.str = ...,
        threshold: builtins.float = ...,
        threshold_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["comparison_operator", b"comparison_operator", "notification_type", b"notification_type", "resource_info", b"resource_info", "threshold", b"threshold", "threshold_type", b"threshold_type"]) -> None: ...

global___BudgetNotification = BudgetNotification

@typing_extensions.final
class BudgetNotificationWithSubscribers(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SUBSCRIBERS_FIELD_NUMBER: builtins.int
    NOTIFICATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def subscribers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BudgetSubscriber]: ...
    @property
    def notification(self) -> global___BudgetNotification: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        subscribers: collections.abc.Iterable[global___BudgetSubscriber] | None = ...,
        notification: global___BudgetNotification | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["notification", b"notification", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["notification", b"notification", "resource_info", b"resource_info", "subscribers", b"subscribers"]) -> None: ...

global___BudgetNotificationWithSubscribers = BudgetNotificationWithSubscribers

@typing_extensions.final
class BudgetSpend(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    UNIT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    amount: builtins.float
    unit: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        amount: builtins.float = ...,
        unit: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "resource_info", b"resource_info", "unit", b"unit"]) -> None: ...

global___BudgetSpend = BudgetSpend

@typing_extensions.final
class BudgetTimePeriod(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    start: builtins.str
    end: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        start: builtins.str = ...,
        end: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end", b"end", "resource_info", b"resource_info", "start", b"start"]) -> None: ...

global___BudgetTimePeriod = BudgetTimePeriod

@typing_extensions.final
class BudgetCostTypes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    INCLUDE_SUPPORT_FIELD_NUMBER: builtins.int
    INCLUDE_OTHER_SUBSCRIPTION_FIELD_NUMBER: builtins.int
    INCLUDE_TAX_FIELD_NUMBER: builtins.int
    INCLUDE_SUBSCRIPTION_FIELD_NUMBER: builtins.int
    USE_BLENDED_FIELD_NUMBER: builtins.int
    INCLUDE_UPFRONT_FIELD_NUMBER: builtins.int
    INCLUDE_DISCOUNT_FIELD_NUMBER: builtins.int
    INCLUDE_CREDIT_FIELD_NUMBER: builtins.int
    INCLUDE_RECURRING_FIELD_NUMBER: builtins.int
    USE_AMORTIZED_FIELD_NUMBER: builtins.int
    INCLUDE_REFUND_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    include_support: builtins.bool
    include_other_subscription: builtins.bool
    include_tax: builtins.bool
    include_subscription: builtins.bool
    use_blended: builtins.bool
    include_upfront: builtins.bool
    include_discount: builtins.bool
    include_credit: builtins.bool
    include_recurring: builtins.bool
    use_amortized: builtins.bool
    include_refund: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        include_support: builtins.bool = ...,
        include_other_subscription: builtins.bool = ...,
        include_tax: builtins.bool = ...,
        include_subscription: builtins.bool = ...,
        use_blended: builtins.bool = ...,
        include_upfront: builtins.bool = ...,
        include_discount: builtins.bool = ...,
        include_credit: builtins.bool = ...,
        include_recurring: builtins.bool = ...,
        use_amortized: builtins.bool = ...,
        include_refund: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["include_credit", b"include_credit", "include_discount", b"include_discount", "include_other_subscription", b"include_other_subscription", "include_recurring", b"include_recurring", "include_refund", b"include_refund", "include_subscription", b"include_subscription", "include_support", b"include_support", "include_tax", b"include_tax", "include_upfront", b"include_upfront", "resource_info", b"resource_info", "use_amortized", b"use_amortized", "use_blended", b"use_blended"]) -> None: ...

global___BudgetCostTypes = BudgetCostTypes

@typing_extensions.final
class BudgetBudgetData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PlannedBudgetLimitsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class CostFiltersEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    BUDGET_LIMIT_FIELD_NUMBER: builtins.int
    TIME_PERIOD_FIELD_NUMBER: builtins.int
    TIME_UNIT_FIELD_NUMBER: builtins.int
    PLANNED_BUDGET_LIMITS_FIELD_NUMBER: builtins.int
    COST_FILTERS_FIELD_NUMBER: builtins.int
    BUDGET_NAME_FIELD_NUMBER: builtins.int
    COST_TYPES_FIELD_NUMBER: builtins.int
    BUDGET_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def budget_limit(self) -> global___BudgetSpend: ...
    @property
    def time_period(self) -> global___BudgetTimePeriod: ...
    time_unit: builtins.str
    @property
    def planned_budget_limits(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def cost_filters(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    budget_name: builtins.str
    @property
    def cost_types(self) -> global___BudgetCostTypes: ...
    budget_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        budget_limit: global___BudgetSpend | None = ...,
        time_period: global___BudgetTimePeriod | None = ...,
        time_unit: builtins.str = ...,
        planned_budget_limits: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        cost_filters: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        budget_name: builtins.str = ...,
        cost_types: global___BudgetCostTypes | None = ...,
        budget_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["budget_limit", b"budget_limit", "cost_types", b"cost_types", "resource_info", b"resource_info", "time_period", b"time_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["budget_limit", b"budget_limit", "budget_name", b"budget_name", "budget_type", b"budget_type", "cost_filters", b"cost_filters", "cost_types", b"cost_types", "planned_budget_limits", b"planned_budget_limits", "resource_info", b"resource_info", "time_period", b"time_period", "time_unit", b"time_unit"]) -> None: ...

global___BudgetBudgetData = BudgetBudgetData

@typing_extensions.final
class Budget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NOTIFICATIONS_WITH_SUBSCRIBERS_FIELD_NUMBER: builtins.int
    BUDGET_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def notifications_with_subscribers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BudgetNotificationWithSubscribers]: ...
    @property
    def budget(self) -> global___BudgetBudgetData: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        notifications_with_subscribers: collections.abc.Iterable[global___BudgetNotificationWithSubscribers] | None = ...,
        budget: global___BudgetBudgetData | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["budget", b"budget", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["budget", b"budget", "notifications_with_subscribers", b"notifications_with_subscribers", "resource_info", b"resource_info"]) -> None: ...

global___Budget = Budget

@typing_extensions.final
class Budgets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUDGET_FIELD_NUMBER: builtins.int
    @property
    def budget(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Budget]: ...
    def __init__(
        self,
        *,
        budget: collections.abc.Iterable[global___Budget] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["budget", b"budget"]) -> None: ...

global___Budgets = Budgets



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ResourceShare(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PRINCIPALS_FIELD_NUMBER: builtins.int
    ALLOW_EXTERNAL_PRINCIPALS_FIELD_NUMBER: builtins.int
    RESOURCE_ARNS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def principals(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    allow_external_principals: builtins.bool
    @property
    def resource_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        principals: collections.abc.Iterable[builtins.str] | None = ...,
        allow_external_principals: builtins.bool = ...,
        resource_arns: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_external_principals", b"allow_external_principals", "name", b"name", "principals", b"principals", "resource_arns", b"resource_arns", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___ResourceShare = ResourceShare

@typing_extensions.final
class RAM(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_SHARE_FIELD_NUMBER: builtins.int
    @property
    def resource_share(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceShare]: ...
    def __init__(
        self,
        *,
        resource_share: collections.abc.Iterable[global___ResourceShare] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_share", b"resource_share"]) -> None: ...

global___RAM = RAM
